durationtools.group_nonreduced_fractions_by_implied_prolation
=============================================================

.. autofunction:: abjad.tools.durationtools.group_nonreduced_fractions_by_implied_prolation.group_nonreduced_fractions_by_implied_prolation
   :noindex:
